==> 2.5.zip: piwigo/language/ta_IN/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'ஒரு மாற்று தீர்வு மேலே பெட்டியில் உரை நகலெடுத்து கோப்புகளை ஒட்டவும் உள்ளது."local/config/database.inc.php"(எச்சரிக்கை: database.inc.php மட்டும், textarea என்ன எந்த வரியை திரும்ப அல்லது இடைவெளி எழுத்து கொண்டிருக்க வேண்டும்)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'கட்டமைப்பு கோப்பு உருவாக்கம் local/config/database.inc.php தோல்வியடைந்தது.';
$lang['Default gallery language'] = 'இயல்புநிலை கேலரி மொழி';
$lang['Download the config file'] = 'Config கோப்பை பதிவிறக்க';
$lang['Hope to see you back soon.'] = 'நீங்கள் விரைவில் திரும்பி பார்க்க நம்புகிறேன்';
$lang['Host'] = 'host';
$lang['Installation'] = 'நிறுவல்';
$lang['It appears your webhost is currently running PHP %s.'] = 'இது உங்களது webhost தற்போது PHP% கள் இயக்கத்தில் தோன்றுகின்றது.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'இது பார்வையாளர்களுக்கு காண்பிக்கப்படும். இது இணைய நிர்வாகத்தில் அவசியம்';
$lang['Just another Piwigo gallery'] = 'மற்றொரு Piwigo கேலரி';
$lang['Keep it confidential, it enables you to access administration panel'] = 'இதை ரகசியமாக வைத்து, இதை நீங்கள் நிர்வாகத்தில் பலகத்தை அணுகுவதற்கு உதவுகிறது';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'உதவி வேண்டுமா? <a உங்கள் கேள்வி கேட்க href="%s"> Piwigo செய்தி பலகை </ a>';
$lang['Database configuration'] = 'தரவுத்தள உள்ளமைவை';
$lang['Database name'] = 'தரவுத்தளத்தின் பெயர்';
$lang['Database table prefix'] = 'தரவுத்தள அட்டவணைகள் முன்னிணைப்பு';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'சர்வர் இணைப்பு வெற்றி, ஆனால் தரவுத்தளத்தின் இணைப்பு சாத்தியம் இல்லை.';
$lang['Congratulations, Piwigo installation is completed'] = 'வாழ்த்துக்கள், Piwigo நிறுவல், முடிக்கப்பட்டது';
$lang['Can\'t connect to server'] = 'சர்வருடன் இணைக்க முடியவில்லை';
$lang['Basic configuration'] = 'அடிப்படை கட்டமைப்பு';
$lang['Admin configuration'] = 'நிர்வாகம் கட்டமைப்பு';
$lang['webmaster login can\'t contain characters \' or "'] = 'வலை மேலாளரின் உள்நுழைவு எழுத்துக்கள் \' or " இல்லாமல் இருக்கலாம்';
$lang['verification'] = 'சரிபார்த்தல்';
$lang['user password given by your host provider'] = 'பயனர் கடவுச்சொல் உங்களுடைய host வழங்குநர் வழங்கப்பட்டது';
$lang['user login given by your host provider'] = 'உங்களுடைய host வழங்குநர் வழங்கப்பட்ட பயனர் உள்நுழைவு';
$lang['localhost or other, supplied by your host provider'] = 'localhost அல்லது வேறு வழங்கப்பட்ட உங்களுடைய host வழங்குநரை';
$lang['please enter your password again'] = 'தயவுசெய்து மறுபடியும் உங்களுடைய கடவுச்சொல்லை உள்ளிடவும்';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'ஆலோசனை தயங்க வேண்டாம் நம்முடைய கருத்துக்களம்
எந்தவொரு உதவிக்கு.:% s';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'நீங்கள் புரவன் வழங்குநரிடம் ஆதரவு பார்க்கவும் மற்றும் பார்க்க வேண்டும் எப்படி நீங்கள் PHP 5 மூலம்  மாற்றலாம்.';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'நீங்கள் கட்டமைப்பு கோப்பினை பதிவிறக்கம் செய்யலாம்
மற்றும் பதிவேற்றலாம் அது உங்களுடைய local/config நிறுவலின் கோப்பகத்தில்';
$lang['also given by your host provider'] = 'மேலும் வழங்கப்பட்டஉங்களுடைய புரவன் வழங்குநரிடம்';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'தரவுத்தள அட்டவணையில் பெயரை முன்னொட்டாக (உங்களுடைய அட்டவணைகளை சிறப்பாக நிர்வகிக்க உதவும்)';
$lang['enter a login for webmaster'] = 'தயவுசெய்து உள்ளிடவும் வலைமேலாளரின் பயனர்பெயர்';
$lang['Welcome to your new installation of Piwigo!'] = 'வரவேற்கிறோம்
உங்களுடைய புதிய Piwigo நிறுவல்! செய்ய';
$lang['Welcome to my photo gallery'] = 'வரவேற்கிறேன்
என்னுடைய புகைப்படம் கேலரிக்கு';
$lang['Try to configure PHP 5'] = 'PHP 5 கட்டமைக்க முயற்சிக்கவும்';
$lang['Visitors will be able to contact site administrator with this mail'] = 'பார்வையாளர்கள் இந்த மின்னஞ்சலை பயன்படுத்தி தளத்தின் நிர்வாகியை தொடர்புகொள்ளவும்';
$lang['User'] = 'பயனர்';
$lang['Sorry!'] = 'வருந்துகிறேன்!';
$lang['Start Install'] = 'நிறுவலை தொடங்கு';
$lang['Password ']['confirm'] = 'கடவுச்சொல்லை [உறுதிப்படுத்தவும்].';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo PHP 5 கட்டமைக்க முடியவில்லை';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo முயற்சி செய்யலாம்
ஒரு. htaccess கோப்பு உருவாக்குவதில் அல்லது மாற்றியமைப்பதன் மூலம் PHP 5 உங்கள் கட்டமைப்பு மாற';
$lang['PHP 5 is required'] = 'PHP 5 தேவைப்படுகிறது';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'குறிப்பு நீங்களே உங்கள் கட்டமைப்பை மாற்ற செய்யலாம், மேலும் Piwigo மீண்டும் துவக்கவும்';
?>

==> 14.5.0.zip: piwigo/language/ta_IN/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'ஒரு மாற்று தீர்வு மேலே பெட்டியில் உரை நகலெடுத்து கோப்புகளை ஒட்டவும் உள்ளது."local/config/database.inc.php"(எச்சரிக்கை: database.inc.php மட்டும், textarea என்ன எந்த வரியை திரும்ப அல்லது இடைவெளி எழுத்து கொண்டிருக்க வேண்டும்)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'கட்டமைப்பு கோப்பு உருவாக்கம் local/config/database.inc.php தோல்வியடைந்தது.';
$lang['Default gallery language'] = 'இயல்புநிலை கேலரி மொழி';
$lang['Download the config file'] = 'Config கோப்பை பதிவிறக்க';
$lang['Hope to see you back soon.'] = 'நீங்கள் விரைவில் திரும்பி பார்க்க நம்புகிறேன்';
$lang['Host'] = 'host';
$lang['Installation'] = 'நிறுவல்';
$lang['It appears your webhost is currently running PHP %s.'] = 'இது உங்களது webhost தற்போது PHP% கள் இயக்கத்தில் தோன்றுகின்றது.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'இது பார்வையாளர்களுக்கு காண்பிக்கப்படும். இது இணைய நிர்வாகத்தில் அவசியம்';
$lang['Just another Piwigo gallery'] = 'மற்றொரு Piwigo கேலரி';
$lang['Keep it confidential, it enables you to access administration panel'] = 'இதை ரகசியமாக வைத்து, இதை நீங்கள் நிர்வாகத்தில் பலகத்தை அணுகுவதற்கு உதவுகிறது';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'உதவி வேண்டுமா? <a உங்கள் கேள்வி கேட்க href="%s"> Piwigo செய்தி பலகை </ a>';
$lang['Database configuration'] = 'தரவுத்தள உள்ளமைவை';
$lang['Database name'] = 'தரவுத்தளத்தின் பெயர்';
$lang['Database table prefix'] = 'தரவுத்தள அட்டவணைகள் முன்னிணைப்பு';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'சர்வர் இணைப்பு வெற்றி, ஆனால் தரவுத்தளத்தின் இணைப்பு சாத்தியம் இல்லை.';
$lang['Congratulations, Piwigo installation is completed'] = 'வாழ்த்துக்கள், Piwigo நிறுவல், முடிக்கப்பட்டது';
$lang['Can\'t connect to server'] = 'சர்வருடன் இணைக்க முடியவில்லை';
$lang['Basic configuration'] = 'அடிப்படை கட்டமைப்பு';
$lang['Admin configuration'] = 'நிர்வாகம் கட்டமைப்பு';
$lang['webmaster login can\'t contain characters \' or "'] = 'வலை மேலாளரின் உள்நுழைவு எழுத்துக்கள் \' or " இல்லாமல் இருக்கலாம்';
$lang['verification'] = 'சரிபார்த்தல்';
$lang['user password given by your host provider'] = 'பயனர் கடவுச்சொல் உங்களுடைய host வழங்குநர் வழங்கப்பட்டது';
$lang['user login given by your host provider'] = 'உங்களுடைய host வழங்குநர் வழங்கப்பட்ட பயனர் உள்நுழைவு';
$lang['localhost or other, supplied by your host provider'] = 'localhost அல்லது வேறு வழங்கப்பட்ட உங்களுடைய host வழங்குநரை';
$lang['please enter your password again'] = 'தயவுசெய்து மறுபடியும் உங்களுடைய கடவுச்சொல்லை உள்ளிடவும்';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'ஆலோசனை தயங்க வேண்டாம் நம்முடைய கருத்துக்களம்
எந்தவொரு உதவிக்கு.:% s';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'நீங்கள் புரவன் வழங்குநரிடம் ஆதரவு பார்க்கவும் மற்றும் பார்க்க வேண்டும் எப்படி நீங்கள் PHP 5.2 மூலம்  மாற்றலாம்.';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'நீங்கள் கட்டமைப்பு கோப்பினை பதிவிறக்கம் செய்யலாம்
மற்றும் பதிவேற்றலாம் அது உங்களுடைய local/config நிறுவலின் கோப்பகத்தில்';
$lang['also given by your host provider'] = 'மேலும் வழங்கப்பட்டஉங்களுடைய புரவன் வழங்குநரிடம்';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'தரவுத்தள அட்டவணையில் பெயரை முன்னொட்டாக (உங்களுடைய அட்டவணைகளை சிறப்பாக நிர்வகிக்க உதவும்)';
$lang['enter a login for webmaster'] = 'தயவுசெய்து உள்ளிடவும் வலைமேலாளரின் பயனர்பெயர்';
$lang['Welcome to your new installation of Piwigo!'] = 'வரவேற்கிறோம்
உங்களுடைய புதிய Piwigo நிறுவல்! செய்ய';
$lang['Welcome to my photo gallery'] = 'வரவேற்கிறேன்
என்னுடைய புகைப்படம் கேலரிக்கு';
$lang['Try to configure PHP 5'] = 'PHP 5.2 கட்டமைக்க முயற்சிக்கவும்';
$lang['Visitors will be able to contact site administrator with this mail'] = 'பார்வையாளர்கள் இந்த மின்னஞ்சலை பயன்படுத்தி தளத்தின் நிர்வாகியை தொடர்புகொள்ளவும்';
$lang['User'] = 'பயனர்';
$lang['Sorry!'] = 'வருந்துகிறேன்!';
$lang['Start Install'] = 'நிறுவலை தொடங்கு';
$lang['Password ']['confirm'] = 'கடவுச்சொல்லை [உறுதிப்படுத்தவும்].';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo PHP 5.2 கட்டமைக்க முடியவில்லை';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo முயற்சி செய்யலாம்
ஒரு. htaccess கோப்பு உருவாக்குவதில் அல்லது மாற்றியமைப்பதன் மூலம் PHP 5.2 உங்கள் கட்டமைப்பு மாற';
$lang['PHP 5 is required'] = 'PHP 5.2 தேவைப்படுகிறது';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'குறிப்பு நீங்களே உங்கள் கட்டமைப்பை மாற்ற செய்யலாம், மேலும் Piwigo மீண்டும் துவக்கவும்';
